@@ -39,10 +39,11 @@ ragnar_store_create_v1 <- function(
     text = character(0)
   ))
 
+  embed <- process_embed_func(embed)
+  embed_func_blob <- blob::blob(serialize(embed, NULL))
   if (is.null(embed)) {
     embedding_size <- NULL
   } else {
-    embed <- process_embed_func(embed)
     check_number_whole(embedding_size, min = 0)
     embedding_size <- as.integer(embedding_size)
 
@@ -86,7 +87,7 @@ ragnar_store_create_v1 <- function(
 
   metadata <- tibble(
     embedding_size,
-    embed_func = blob::blob(serialize(embed, NULL)),
+    embed_func = embed_func_blob,
     schema = blob::blob(serialize(schema, NULL)),
     name = name,
     title = title
@@ -127,6 +128,7 @@ ragnar_store_create_v1 <- function(
     con,
     glue(
       "
+    SET enable_progress_bar = false;
     CREATE SEQUENCE chunk_id_sequence START 1;
     CREATE TABLE chunks (
       chunk_id INTEGER DEFAULT nextval('chunk_id_sequence'),
@@ -136,6 +138,7 @@ ragnar_store_create_v1 <- function(
   )
 
   DuckDBRagnarStore(
+    location = normalizePath(location, winslash = "/", mustWork = FALSE),
     embed = embed,
     schema = schema,
     con = con,
