@@ -35,7 +35,7 @@ test_that("extra cols works", {
   # Can't insert chunks that don't match the types
   expect_error(
     ragnar_store_insert(store, chunks_not_ok),
-    regexp = "Can't convert"
+    regexp = "convert"
   )
 
   chunks_ok <- chunks |>
